@@ -178,7 +178,7 @@ class Peer(object):
                 
                 if connection.incoming:
                     # Remember the host connecting in to us
-                    self.incoming_hosts.add(connection.transport.getPeer()[0])
+                    self.incoming_hosts.add(connection.transport.getPeer().host)
                 
                 return True
         
@@ -195,7 +195,7 @@ class Peer(object):
             
             if connection.incoming:
                 # This was a connection we got, so throw it out of that set.
-                self.incoming_hosts.discard(connection.transport.getPeer()[0])
+                self.incoming_hosts.discard(connection.transport.getPeer().host)
         
     
     def lost_outgoing_connection(self, host):
