@@ -985,9 +985,14 @@ class CoinBlockchain(TransactionalBlockchain):
                 
                 if fee >= min_fee:
                     # This transaction pays enough. Use it.
-                    to_include.append(transaction)
-                    total_fee += fee
-                    next_state.apply_transaction(transaction)
+                    
+                    if self.verify_transaction(transaction_bytes, 
+                        self.highest_block, next_state, advance=True):
+                    
+                        # The transaction is OK to go in the block. We checked
+                        # it earlier, but we should probably check it again.
+                        to_include.append(transaction)
+                        total_fee += fee
             
             # Add a transaction that gives all the generated coins and fees to
             # us.
